### Name: vario.pgs
### Title: Calculate the variogram of the Underlying GRFs from the
###   categories (e.g lithofacies)
### Aliases: vario.pgs
### Keywords: spatial htest

### ** Examples


## Not run: 
##D #This part contains several independent examples.
##D # Example 1: independent bigaussian model with stationary proportions
##D # Example 2: correlated bigaussian model ("residuals" type) 
##D   	     with estimation of the correlation coefficient
##D # Example 3: correlated bigaussian model ("symmetrical" type). 
##D   	     The interest is the particular form of the 
##D 	     cross-correlation.
##D # Example 4: Shifted bigaussian ("full" type).
##D # Example 5: Non-stationary proportions
##D 
##D #########################################
##D #              Example 1		#
##D #########################################
##D 
##D #Simulation of 2 independent GRFs and one categorical variable:
##D 
##D set.seed(234)
##D data(Exdemo_simpgs_std.rule)
##D db=db.create(x1=runif(1000),x2=runif(1000),ndim=2)
##D model=model.create(vartype="Gaussian",range=.2,ndim=2)
##D model2=model.create(vartype="Exponential",range=.3,ndim=2)   
##D db=simtub(dbout=db,model=model,nbtuba=2000)
##D vario1=vario.calc(db,nlag=30)
##D db=simtub(dbout=db,model=model2,nbtuba=2000)
##D vario2=vario.calc(db,nlag=30)
##D db=db.locate(db,4:5,"z")
##D db=db.rule(db,rule=Exdemo_simpgs_std.rule)
##D 
##D #Call vario.pgs
##D vario=vario.pgs(db,rule=Exdemo_simpgs_std.rule,nlag=30)
##D 
##D #Graphical representation of the Rule
##D plot(Exdemo_simpgs_std.rule)
##D title("Composition rule")
##D dev.off()
##D 
##D #Graphical representation of the data and the variograms
##D split.screen(c(2,2))
##D 
##D #The data
##D screen(1)
##D plot(db[,2],db[,3],col=db[,6],pch=16,xlab="",ylab="",cex=.6)
##D title("Data: 3 categories")
##D 
##D #Legend for the variograms
##D screen(2)
##D plot(c(0,10),c(0,10),cex=0,xaxt="n",yaxt="n",xlab="",ylab="")
##D legend(0,5,legend=c("Models","Vario from GRFs","Vario from Categories"),
##D 		col=c(6,4,1),lty=c(1,1,NA),pch=c(NA,NA,1),box.col=0)
##D title("Legend for the variograms")
##D 
##D #GRF1
##D screen(3)
##D v1=vario.reduce(vario=vario,varcols=1,flag.vario=TRUE)
##D plot(vario1,col=4,xlab="h",ylab=expression(gamma),reset=FALSE)
##D points(v1[1]$hh,v1[1]$gg)
##D plot(model,vario=v1,add=TRUE,col=6)
##D title("Variograms of the GRF #1")
##D 
##D #GRF2
##D screen(4)
##D v2=vario.reduce(vario=vario,varcols=2,flag.vario=TRUE)
##D plot(vario2,col=4,xlab="h",ylab=expression(gamma),reset=FALSE)
##D points(v2[1]$hh,v2[1]$gg)
##D plot(model2,vario=v2,pch=1,add=TRUE,col=6)
##D title("Variograms of the GRF #2")
##D 
##D rm(db,Exdemo_simpgs_std.rule,model,model2,v1,v2,vario,vario1,vario2)
##D par(mfrow=c(1,1))
##D 
##D #########################################
##D #              Example 2		#
##D #########################################
##D 
##D 
##D set.seed(23)
##D data(Exdemo_simpgs_std.rule)
##D db=db.create(flag.grid=TRUE,nx=5000,ndim=1)
##D r=-.7
##D model=model.create(vartype="Gaussian",range=20,sill=matrix(c(1,r,r,r^2),2),
##D ndim=1)
##D model=model.create(vartype="Exponential",range=50,sill=matrix(c(0,0,0,1-r^2),2),
##D model=model,ndim=1)   
##D Exdemo_simpgs_std.rule$rho=r
##D db=simtub(dbout=db,model=model,nbtuba=2000)
##D db=db.rule(db,rule=Exdemo_simpgs_std.rule)
##D 
##D #1st call of vario.pgs to determine rho
##D 
##D vario=vario.pgs(db,rule=Exdemo_simpgs_std.rule,nlag=5,lag=1,flag.rho=T)
##D Exdemo_simpgs_std.rule$rho=vario$vars[2]
##D 
##D #Second call with fixed and estimated rho
##D 
##D Exdemo_simpgs_std.rule$rho=vario$vars[2]
##D vario=vario.pgs(db,rule=Exdemo_simpgs_std.rule,nlag=50,lag=1,flag.rho=F)
##D 
##D 
##D plot(model,as.cov=TRUE,vario=vario)
##D plot(vario,add=TRUE,col=2)
##D 
##D plot(db[,2],db[,3],col=db[,6],pch=16,xlab="",ylab="",cex=.6)
##D 
##D #########################################
##D #              Example 3		#
##D #########################################
##D 
##D 
##D 
##D r1=-1
##D r2=0
##D s11=.4
##D s12=.4
##D range1=500
##D 
##D s21=.6
##D s22=.6
##D range2=10000
##D 
##D p1=.8
##D p2=p3=.09
##D p4=1-p1-p2-p3
##D 
##D rule=rule.create(c("S","T","F1","F2","T","F3","F4"))
##D model=model.create(melem.name(5),
##D sill=matrix(c(s11,sqrt(s11*s12)*r1,sqrt(s11*s12)*r1,s12),2),range=range1,ndim=2)
##D model=model.create(melem.name(5),
##D sill=matrix(c(s21,sqrt(s21*s22)*r2,sqrt(s21*s22)*r2,s22),2),range=range2,
##D model=model,ndim=2)
##D r=model.eval(model,0,as.cov=T,jvar=2)
##D rule$rho=r
##D curve(model.eval(model,x,as.cov=T,ivar=1,jvar=2,),0,6000,ylab="",
##D ylim=c(-1,1),n=1000)
##D 
##D db=db.create(nx=c(200,200),dx=c(100,100))
##D db=simtub(dbout=db,model=model,nbtuba=1000)
##D db=db.rule(db,rule=rule,props=c(p1,p2,p3,p4))
##D plot(db[,2],db[,3],pch=16,col=db[,6])
##D 
##D vario=vario.pgs(db,rule=rule,lag=1,nlag=50,flag.rho=F,model.type="symmetrical",props=c(p1,p2,p3,p4))
##D plot(vario)
##D plot(model,vario=vario,add=T,col=2)
##D 
##D 
##D #########################################
##D #              Example 4		#
##D #########################################
##D 
##D 
##D set.seed(2233)
##D data(Exdemo_simpgs_std.rule)
##D model=model.create(melem.name(2),range=50,ndim=1)
##D data(Exdemo_simpgs_std.rule)
##D Exdemo_simpgs_std.rule$rho=model.eval(model,10,as.cov=T)
##D db=db.create(nx=5010)
##D db=simtub(dbout=db,model=model,nbtuba=2000)
##D db=db.create(nx=5000,z1=db[1:5000,3],z2=db[11:5010,3])
##D db=db.rule(db,rule=Exdemo_simpgs_std.rule)
##D Exdemo_simpgs_std.rule$rho=0
##D vario=vario.pgs(db,rule=Exdemo_simpgs_std.rule,lag=1,nlag=5,flag.rho=T,model.type="full")
##D vario=vario.pgs(db,rule=Exdemo_simpgs_std.rule,lag=1,nlag=50,flag.rho=F,model.type="full")
##D plot(vario)
##D x11()
##D plot(vario[1]$hh[103:201],vario[1]$gg[103:201],xlab="h",ylab=expression(gamma),type="l")
##D abline(v=0)
##D curve(model.eval(model,x+10,as.cov=T),add=T,col=2)
##D 
##D 
##D #########################################
##D #              Example 5		#
##D #########################################
##D 
##D 
##D 
##D set.seed(23)
##D data(Exdemo_simpgs_std.rule)
##D db=db.create(nx=5000)
##D r=-.7
##D model=model.create(vartype="Gaussian",range=20,
##D sill=matrix(c(1,r,r,r^2),2))
##D model=model.create(vartype="Exponential",range=50,
##D sill=matrix(c(0,0,0,1-r^2),2),model=model)   
##D Exdemo_simpgs_std.rule$rho=r
##D db=simtub(dbout=db,model=model,nbtuba=2000)
##D 
##D #Simulation of the proportions
##D model.prop=model.create(vartype="Gaussian",range=1000)
##D db.prop=db.create(nx=5000)
##D db.prop=simtub(dbout=db.prop,model=model.prop,seed=12213,nbtuba=2000,nbsimu=3)
##D proportions=exp(db.prop[,3:4])/(apply(exp(db.prop[,3:4]),1,sum)+1)
##D proportions=cbind(proportions,1-apply(proportions[,1:2],1,sum))
##D 
##D db=db.add(db,proportions,locnames=c("p1","p2","p3"))
##D db=db.rule(db,rule=Exdemo_simpgs_std.rule)
##D 
##D 
##D par(mfrow=c(1,5))
##D plot(c(0,1),c(1,5000),cex=0,xlab="Proportions",ylab="",xaxp=c(0,1,2),yaxp=c(0,5000,5),cex.lab=1.2,cex.axis=1.4)
##D polygon(c(0,db[,5],0),c(1,1:5000,5000),col=1)
##D polygon(c(db[5000:1,5],1-db[,7]),c(5000:1,1:5000),col=2)
##D polygon(c(1-db[,7],1,1),c(1:5000,5000,1),col=3)
##D 
##D db.prop=db.prop.thresh(db.prop,db,rule=Exdemo_simpgs_std.rule,model=model)
##D plot(db[,3],1:5000,type="l",xlab="1st GRF",ylab="",xaxp=c(3,3,2),yaxt="n",cex.lab=1.2,cex.axis=1.4)
##D lines(db.prop[,6],1:5000,col=2,lwd=1.5)
##D 
##D plot(c(0,1),c(1,5000),cex=0,xlab="Facies",ylab="",xaxt="n",yaxt="n",cex.axis=1.4)
##D from=c(1,.5+(1:4999)[db[-1,8]!=db[-5000,8]])
##D to=c(from[-1],5000)
##D for(i in 1:length(from))
##D polygon(c(0,1,1,0),c(from[i],from[i],to[i],to[i]),col=db[1,8],db[-1][db[-1,8]!=db[-5000,8],8][i])
##D vario=vario.pgs(db,rule=Exdemo_simpgs_std.rule,lag=1,nlag=50,flag.rho=F)
##D plot(vario)
##D plot(model,vario=vario,add=T,col=2)
## End(Not run)



